clear all, close all

%% Physical parameters

% Geometrical properties
ro = .175/2;                              % External radius [m]
ri = 0.0788;                              % Internal radius [m]
Pi_cat = 100*2*pi*ri;                     % Total catalyst cell perimeter [m] 
Aw_cat = 1/10*pi*(ro-ri);                 % Solid cross-sectional area of catalyst [m2]
L = 2*.0577;                              % Monolith length [m]

% Substrate properties
lambda_w = 1.5;                           % Wall thermal conductivity [J/m/s/K]
rho_w = 2600;                             % Wall density [kg/m3]
Cp_w = 1000;                              % Wall heat capacity [J/kg/K]
hi= 563.45;                               % Internal heat transfert coefficient [J/m2/s/K]
% Gas properties
Cp_g = 962;                               % Gas heat capacity [J/kg/K]
rho_g = 1.225;                            % Air density [kg/m3]

% Operating point
m_dot = 1e-2;                             % Mass flow rate [kg/s]

% PDE model parameters
alpha_w = lambda_w/(rho_w*Cp_w);
beta_w = hi*Pi_cat/(Aw_cat*rho_w*Cp_w);
gamma_w = 1/(Aw_cat*rho_w*Cp_w);

alpha_g = m_dot/(Aw_cat*rho_g);
beta_g = hi*Pi_cat/(Aw_cat*rho_g*Cp_g);

%% Simulation parameters
N = 51;                                   % Number of computational elements
dx = L/(N-1);                             % Spatial sampling step
dt = .01;                                 % Time sampling step
Tsim = 200;

Tg_init = 20*ones(N,1);
Tw_init = 20*ones(N,1);
f_init = zeros(round(Tsim/dt),1);

x0 = 20*dx;
epsilon = dx;